random123

Counter-based Random Number Generators
git clone git://git.meso-star.com/random123.git
Log | Files | Refs | README | LICENSE

kat_cuda.cu (2521B)


      1 /*
      2 Copyright 2010-2011, D. E. Shaw Research.
      3 All rights reserved.
      4 
      5 Redistribution and use in source and binary forms, with or without
      6 modification, are permitted provided that the following conditions are
      7 met:
      8 
      9 * Redistributions of source code must retain the above copyright
     10   notice, this list of conditions, and the following disclaimer.
     11 
     12 * Redistributions in binary form must reproduce the above copyright
     13   notice, this list of conditions, and the following disclaimer in the
     14   documentation and/or other materials provided with the distribution.
     15 
     16 * Neither the name of D. E. Shaw Research nor the names of its
     17   contributors may be used to endorse or promote products derived from
     18   this software without specific prior written permission.
     19 
     20 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
     21 "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
     22 LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
     23 A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
     24 OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
     25 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
     26 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
     27 DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
     28 THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
     29 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
     30 OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
     31 */
     32 #include "util_cuda.h"
     33 #include "kat_main.h"
     34 
     35 #define KAT_KERNEL __global__
     36 #define KAT_GLOBAL
     37 #include "kat_dev_execute.h"
     38 
     39 void host_execute_tests(kat_instance *tests_host, unsigned ntests){
     40     CUDAInfo *infop;
     41     kat_instance *tests_dev;
     42     size_t tests_sz;
     43 
     44     infop = cuda_init(NULL);
     45 
     46     tests_sz = sizeof(tests_host[0]) * (ntests+1); // +1 for sentinel test with method==last
     47     CHECKCALL(cudaMalloc(&tests_dev, tests_sz));
     48     CHECKCALL(cudaMemcpy(tests_dev, tests_host, tests_sz, cudaMemcpyHostToDevice));
     49 
     50     printf("starting %u tests on 1 blocks with 1 threads/block\n", ntests);
     51     fflush(stdout);
     52 
     53     // TO DO:  call this with parallelism, <<<infop->blocks_per_grid, infop->threads_per_block>>>
     54     // and then insure that each of the threads got the same result.
     55     dev_execute_tests<<<1, 1>>>(tests_dev);
     56 
     57     CHECKCALL(cudaDeviceSynchronize());
     58     CHECKCALL(cudaMemcpy(tests_host, tests_dev, tests_sz, cudaMemcpyDeviceToHost));
     59     CHECKCALL(cudaFree(tests_dev));
     60     cuda_done(infop);
     61 }
     62